@@ -123,6 +123,15 @@ def login_token_helper(ctx, value):
             "Please copy the access token and paste it here. (your input is not displayed)",
             hide_input=True,
         )
+
+    # Detect pasting shortcut malfunction (Windows users)
+    # When this shortcut is disabled then the character \x16
+    # (which will appear as ^V) is generated by the terminal when trying to use it.
+    if "".join(set(value)) == "\x16":
+        click.secho(
+            "\nThe access token provided indicates a copy/paste malfunction.\nRead more here: https://r.divio.com/divio-login-windows-users.",
+            fg="yellow",
+        )
     return value
 
 
