@@ -12,3 +12,7 @@ DIVIO_GLOBAL_CONFIG_FILE = os.path.join(
     os.getenv("XDG_CONFIG_HOME", os.path.expanduser("~/.config")),
     "divio/config.json",
 )
+DEFAULT_SENTRY_DSN = (
+    "https://c81d7d22230841d7ae752bac26c84dcf@o1163.ingest.sentry.io/6001539"
+)
+DEFAULT_DOCKER_COMPOSE_CMD = ["docker-compose"]
